@@ -24,7 +24,7 @@
  *   Robert Bragg <robert@linux.intel.com>
  */
 
-#if !defined(__COGL_H_INSIDE__) && !defined(CLUTTER_COMPILATION)
+#if !defined(__COGL_H_INSIDE__) && !defined(COGL_COMPILATION)
 #error "Only <cogl/cogl.h> can be included directly."
 #endif
 
@@ -68,7 +68,7 @@ G_BEGIN_DECLS
  */
 CoglAttributeBuffer *
 cogl_attribute_buffer_new (CoglContext *context,
-                           gsize bytes,
+                           size_t bytes,
                            const void *data);
 
 /**
@@ -77,13 +77,13 @@ cogl_attribute_buffer_new (CoglContext *context,
  *
  * Gets whether the given object references a #CoglAttributeBuffer.
  *
- * Returns: %TRUE if the handle references a #CoglAttributeBuffer,
+ * Returns: %TRUE if @object references a #CoglAttributeBuffer,
  *   %FALSE otherwise
  *
  * Since: 1.4
  * Stability: Unstable
  */
-gboolean
+CoglBool
 cogl_is_attribute_buffer (void *object);
 
 G_END_DECLS
