@@ -30,7 +30,7 @@
 #include "cogl-boxed-value.h"
 #include "cogl-context-private.h"
 
-gboolean
+CoglBool
 _cogl_boxed_value_equal (const CoglBoxedValue *bva,
                          const CoglBoxedValue *bvb)
 {
@@ -126,9 +126,9 @@ _cogl_boxed_value_set_x (CoglBoxedValue *bv,
                          int size,
                          int count,
                          CoglBoxedType type,
-                         gsize value_size,
-                         gconstpointer value,
-                         gboolean transpose)
+                         size_t value_size,
+                         const void *value,
+                         CoglBool transpose)
 {
   if (count == 1)
     {
@@ -223,7 +223,7 @@ void
 _cogl_boxed_value_set_matrix (CoglBoxedValue *bv,
                               int dimensions,
                               int count,
-                              gboolean transpose,
+                              CoglBool transpose,
                               const float *value)
 {
   _cogl_boxed_value_set_x (bv,
