@@ -41,12 +41,16 @@
 #include "cogl-buffer-private.h"
 #include "cogl-bitmask.h"
 #include "cogl-atlas.h"
+#include "cogl-driver.h"
 #include "cogl-texture-driver.h"
 #include "cogl-pipeline-cache.h"
 #include "cogl-texture-2d.h"
 #include "cogl-texture-3d.h"
 #include "cogl-texture-rectangle.h"
+#include "cogl-sampler-cache-private.h"
 #include "cogl-gpu-info-private.h"
+#include "cogl-gl-header.h"
+#include "cogl-framebuffer-private.h"
 
 typedef struct
 {
@@ -67,7 +71,8 @@ struct _CoglContext
      determine certain workarounds */
   CoglGpuInfo gpu;
 
-  /* vtable for the texture driver functions */
+  /* vtables for the driver functions */
+  const CoglDriverVtable *driver_vtable;
   const CoglTextureDriver *texture_driver;
 
   /* Features cache */
@@ -96,7 +101,7 @@ struct _CoglContext
   CoglBitmask       enable_custom_attributes_tmp;
   CoglBitmask       changed_bits_tmp;
 
-  gboolean          legacy_backface_culling_enabled;
+  CoglBool          legacy_backface_culling_enabled;
 
   /* A few handy matrix constants */
   CoglMatrix        identity_matrix;
@@ -106,14 +111,17 @@ struct _CoglContext
      calling it multiple times */
   CoglMatrixMode    flushed_matrix_mode;
 
-  /* The matrix stack that should be used for the next render */
-  CoglMatrixStack  *current_projection_stack;
-  CoglMatrixStack  *current_modelview_stack;
+  /* The matrix stack entries that should be flushed during the next
+   * pipeline state flush */
+  CoglMatrixEntry *current_projection_entry;
+  CoglMatrixEntry *current_modelview_entry;
 
-  /* The last matrix stack with age that was flushed to the GL matrix
-     builtins */
-  CoglMatrixStackCache builtin_flushed_projection;
-  CoglMatrixStackCache builtin_flushed_modelview;
+  CoglMatrixEntry identity_entry;
+
+  /* A cache of the last (immutable) matrix stack entries that were
+   * flushed to the GL matrix builtins */
+  CoglMatrixEntryCache builtin_flushed_projection;
+  CoglMatrixEntryCache builtin_flushed_modelview;
 
   GArray           *texture_units;
   int               active_texture_unit;
@@ -150,44 +158,50 @@ struct _CoglContext
   /* Some simple caching, to minimize state changes... */
   CoglPipeline     *current_pipeline;
   unsigned long     current_pipeline_changes_since_flush;
-  gboolean          current_pipeline_skip_gl_color;
+  CoglBool          current_pipeline_skip_gl_color;
   unsigned long     current_pipeline_age;
 
-  gboolean          gl_blend_enable_cache;
+  CoglBool          gl_blend_enable_cache;
 
-  gboolean              depth_test_enabled_cache;
+  CoglBool              depth_test_enabled_cache;
   CoglDepthTestFunction depth_test_function_cache;
-  gboolean              depth_writing_enabled_cache;
+  CoglBool              depth_writing_enabled_cache;
   float                 depth_range_near_cache;
   float                 depth_range_far_cache;
 
-  gboolean              legacy_depth_test_enabled;
+  CoglBool              legacy_depth_test_enabled;
 
   CoglBuffer       *current_buffer[COGL_BUFFER_BIND_TARGET_COUNT];
 
   /* Framebuffers */
   GSList           *framebuffer_stack;
-  CoglHandle        window_buffer;
+  CoglFramebuffer  *window_buffer;
   unsigned long     current_draw_buffer_state_flushed;
   unsigned long     current_draw_buffer_changes;
   CoglFramebuffer  *current_draw_buffer;
   CoglFramebuffer  *current_read_buffer;
 
+  gboolean have_last_offscreen_allocate_flags;
+  CoglOffscreenAllocateFlags last_offscreen_allocate_flags;
+
+  CoglGLES2Context *current_gles2_context;
+  GQueue gles2_context_stack;
+
   /* Primitives */
   CoglPath         *current_path;
   CoglPipeline     *stencil_pipeline;
 
   /* Pre-generated VBOs containing indices to generate GL_TRIANGLES
      out of a vertex array of quads */
-  CoglHandle        quad_buffer_indices_byte;
+  CoglIndices      *quad_buffer_indices_byte;
   unsigned int      quad_buffer_indices_len;
-  CoglHandle        quad_buffer_indices;
+  CoglIndices      *quad_buffer_indices;
 
   CoglIndices      *rectangle_byte_indices;
   CoglIndices      *rectangle_short_indices;
   int               rectangle_short_indices_len;
 
-  gboolean          in_begin_gl_block;
+  CoglBool          in_begin_gl_block;
 
   CoglPipeline     *texture_download_pipeline;
   CoglPipeline     *blit_texture_pipeline;
@@ -199,7 +213,7 @@ struct _CoglContext
      displaying the quad batches. It needs to be global so that it can
      be reset by cogl_clear. It needs to be reset to increase the
      chances of getting the same colour during an animation */
-  guint8            journal_rectangles_color;
+  uint8_t            journal_rectangles_color;
 
   /* Cached values for GL_MAX_TEXTURE_[IMAGE_]UNITS to avoid calling
      glGetInteger too often */
@@ -214,7 +228,7 @@ struct _CoglContext
   CoglPipelineProgramType current_vertex_program_type;
   GLuint                  current_gl_program;
 
-  gboolean current_gl_dither_enabled;
+  CoglBool current_gl_dither_enabled;
   CoglColorMask current_gl_color_mask;
 
   /* List of types that will be considered a subclass of CoglTexture in
@@ -233,7 +247,7 @@ struct _CoglContext
      doesn't need to be a valid pointer. We can't just use NULL in
      current_clip_stack to mark a dirty state because NULL is a valid
      stack (meaning no clipping) */
-  gboolean          current_clip_stack_valid;
+  CoglBool          current_clip_stack_valid;
   /* The clip state that was flushed. This isn't intended to be used
      as a stack to push and pop new entries. Instead the current stack
      that the user wants is part of the framebuffer state. This is
@@ -245,16 +259,18 @@ struct _CoglContext
      state. If TRUE then any further use of the stencil buffer (such
      as for drawing paths) would need to be merged with the existing
      stencil buffer */
-  gboolean          current_clip_stack_uses_stencil;
+  CoglBool          current_clip_stack_uses_stencil;
 
   /* This is used as a temporary buffer to fill a CoglBuffer when
      cogl_buffer_map fails and we only want to map to fill it with new
      data */
   GByteArray       *buffer_map_fallback_array;
-  gboolean          buffer_map_fallback_in_use;
+  CoglBool          buffer_map_fallback_in_use;
 
   CoglWinsysRectangleState rectangle_state;
 
+  CoglSamplerCache *sampler_cache;
+
   /* FIXME: remove these when we remove the last xlib based clutter
    * backend. they should be tracked as part of the renderer but e.g.
    * the eglx backend doesn't yet have a corresponding Cogl winsys
@@ -318,7 +334,7 @@ _cogl_context_get_winsys (CoglContext *context);
  * to know when to re-query the GL extensions. The backend should also
  * check whether the GL context is supported by Cogl. If not it should
  * return FALSE and set @error */
-gboolean
+CoglBool
 _cogl_context_update_features (CoglContext *context,
                                GError **error);
 
@@ -330,11 +346,17 @@ if (ctxvar == NULL) return retval;
 #define NO_RETVAL
 
 void
-_cogl_context_set_current_projection (CoglContext *context,
-                                      CoglMatrixStack *stack);
+_cogl_context_set_current_projection_entry (CoglContext *context,
+                                            CoglMatrixEntry *entry);
 
 void
-_cogl_context_set_current_modelview (CoglContext *context,
-                                     CoglMatrixStack *stack);
+_cogl_context_set_current_modelview_entry (CoglContext *context,
+                                           CoglMatrixEntry *entry);
+
+const char *
+_cogl_context_get_gl_extensions (CoglContext *context);
+
+const char *
+_cogl_context_get_gl_version (CoglContext *context);
 
 #endif /* __COGL_CONTEXT_PRIVATE_H */
