@@ -24,7 +24,7 @@
  *
  */
 
-#if !defined(__COGL_H_INSIDE__) && !defined(CLUTTER_COMPILATION)
+#if !defined(__COGL_H_INSIDE__) && !defined(COGL_COMPILATION)
 #error "Only <cogl/cogl.h> can be included directly."
 #endif
 
@@ -152,7 +152,7 @@ cogl_display_get_renderer (CoglDisplay *display);
  * Since: 1.10
  * Stability: unstable
  */
-gboolean
+CoglBool
 cogl_display_setup (CoglDisplay *display,
                     GError **error);
 
@@ -171,24 +171,6 @@ cogl_gdl_display_set_plane (CoglDisplay *display,
                             gdl_plane_id_t plane);
 #endif
 
-#ifdef COGL_HAS_WAYLAND_EGL_SERVER_SUPPORT
-/**
- * cogl_wayland_display_set_compositor_display:
- * @display: a #CoglDisplay
- * @wayland_display: A compositor's Wayland display pointer
- *
- * Informs Cogl of a compositor's Wayland display pointer. This
- * enables Cogl to register private wayland extensions required to
- * pass buffers between the clients and compositor.
- *
- * Since: 1.10
- * Stability: unstable
- */
-void
-cogl_wayland_display_set_compositor_display (CoglDisplay *display,
-                                          struct wl_display *wayland_display);
-#endif
-
 /**
  * cogl_is_display:
  * @object: A #CoglObject pointer
@@ -200,7 +182,7 @@ cogl_wayland_display_set_compositor_display (CoglDisplay *display,
  * Since: 1.10
  * Stability: unstable
  */
-gboolean
+CoglBool
 cogl_is_display (void *object);
 
 G_END_DECLS
