@@ -126,6 +126,30 @@ COGL_STRUCT_SIZE_ASSERT (CoglMatrix, 128 + sizeof (unsigned long) * 3);
 void
 cogl_matrix_init_identity (CoglMatrix *matrix);
 
+/**
+ * cogl_matrix_init_translation:
+ * @matrix: A 4x4 transformation matrix
+ * @tx x coordinate of the translation vector
+ * @ty y coordinate of the translation vector
+ * @tz z coordinate of the translation vector
+ *
+ * Resets matrix to the (tx, ty, tz) translation matrix:
+ *
+ * |[
+ *   .xx=1; .xy=0; .xz=0; .xw=tx;
+ *   .yx=0; .yy=1; .yz=0; .yw=ty;
+ *   .zx=0; .zy=0; .zz=1; .zw=tz;
+ *   .wx=0; .wy=0; .wz=0; .ww=1;
+ * ]|
+ *
+ * Since: 2.0
+ */
+void
+cogl_matrix_init_translation (CoglMatrix *matrix,
+                              float       tx,
+                              float       ty,
+                              float       tz);
+
 /**
  * cogl_matrix_multiply:
  * @result: The address of a 4x4 matrix to store the result in
@@ -161,6 +185,36 @@ cogl_matrix_rotate (CoglMatrix *matrix,
 		    float y,
 		    float z);
 
+#ifdef COGL_ENABLE_EXPERIMENTAL_API
+/**
+ * cogl_matrix_rotate_quaternion:
+ * @matrix: A 4x4 transformation matrix
+ * @quaternion: A quaternion describing a rotation
+ *
+ * Multiplies @matrix with a rotation transformation described by the
+ * given #CoglQuaternion.
+ *
+ * Since: 2.0
+ */
+void
+cogl_matrix_rotate_quaternion (CoglMatrix *matrix,
+                               const CoglQuaternion *quaternion);
+
+/**
+ * cogl_matrix_rotate_euler:
+ * @matrix: A 4x4 transformation matrix
+ * @euler: A euler describing a rotation
+ *
+ * Multiplies @matrix with a rotation transformation described by the
+ * given #CoglEuler.
+ *
+ * Since: 2.0
+ */
+void
+cogl_matrix_rotate_euler (CoglMatrix *matrix,
+                          const CoglEuler *euler);
+#endif
+
 /**
  * cogl_matrix_translate:
  * @matrix: A 4x4 transformation matrix
@@ -463,12 +517,21 @@ cogl_matrix_get_array (const CoglMatrix *matrix);
  * @quaternion: A #CoglQuaternion
  *
  * Initializes @matrix from a #CoglQuaternion rotation.
- *
- * Return value: a pointer to the float array
  */
 void
 cogl_matrix_init_from_quaternion (CoglMatrix *matrix,
-                                  CoglQuaternion *quaternion);
+                                  const CoglQuaternion *quaternion);
+
+/**
+ * cogl_matrix_init_from_euler:
+ * @matrix: A 4x4 transformation matrix
+ * @euler: A #CoglEuler
+ *
+ * Initializes @matrix from a #CoglEuler rotation.
+ */
+void
+cogl_matrix_init_from_euler (CoglMatrix *matrix,
+                             const CoglEuler *euler);
 #endif
 
 /**
@@ -483,8 +546,8 @@ cogl_matrix_init_from_quaternion (CoglMatrix *matrix,
  *
  * Since: 1.4
  */
-gboolean
-cogl_matrix_equal (gconstpointer v1, gconstpointer v2);
+CoglBool
+cogl_matrix_equal (const void *v1, const void *v2);
 
 /**
  * cogl_matrix_copy:
@@ -533,7 +596,7 @@ cogl_matrix_free (CoglMatrix *matrix);
  *
  * Since: 1.2
  */
-gboolean
+CoglBool
 cogl_matrix_get_inverse (const CoglMatrix *matrix,
                          CoglMatrix *inverse);
 
@@ -584,11 +647,11 @@ cogl_matrix_transform_point (const CoglMatrix *matrix,
  * |[
  * typedef struct {
  *   float x,y;
- *   guint8 r,g,b,a;
+ *   uint8_t r,g,b,a;
  *   float s,t,p;
  * } MyInVertex;
  * typedef struct {
- *   guint8 r,g,b,a;
+ *   uint8_t r,g,b,a;
  *   float x,y,z;
  * } MyOutVertex;
  * MyInVertex vertices[N_VERTICES];
@@ -639,11 +702,11 @@ cogl_matrix_transform_points (const CoglMatrix *matrix,
  * |[
  * typedef struct {
  *   float x,y;
- *   guint8 r,g,b,a;
+ *   uint8_t r,g,b,a;
  *   float s,t,p;
  * } MyInVertex;
  * typedef struct {
- *   guint8 r,g,b,a;
+ *   uint8_t r,g,b,a;
  *   float x,y,z;
  * } MyOutVertex;
  * MyInVertex vertices[N_VERTICES];
@@ -684,7 +747,7 @@ cogl_matrix_project_points (const CoglMatrix *matrix,
  * Returns: %TRUE if @matrix is an identity matrix else %FALSE
  * Since: 1.8
  */
-gboolean
+CoglBool
 cogl_matrix_is_identity (const CoglMatrix *matrix);
 
 /**
