@@ -158,7 +158,7 @@ _cogl_set_active_texture_unit (int unit_index)
 void
 _cogl_bind_gl_texture_transient (GLenum gl_target,
                                  GLuint gl_texture,
-                                 gboolean is_foreign)
+                                 CoglBool is_foreign)
 {
   CoglTextureUnit *unit;
 
@@ -389,7 +389,7 @@ _cogl_use_vertex_program (GLuint gl_program, CoglPipelineProgramType type)
 
 #if defined(HAVE_COGL_GLES2) || defined(HAVE_COGL_GL)
 
-static gboolean
+static CoglBool
 blend_factor_uses_constant (GLenum blend_factor)
 {
   return (blend_factor == GL_CONSTANT_COLOR ||
@@ -401,11 +401,20 @@ blend_factor_uses_constant (GLenum blend_factor)
 #endif
 
 static void
-flush_depth_state (CoglDepthState *depth_state)
+flush_depth_state (CoglContext *ctx,
+                   CoglDepthState *depth_state)
 {
-  _COGL_GET_CONTEXT (ctx, NO_RETVAL);
+  if (ctx->depth_test_enabled_cache != depth_state->test_enabled)
+    {
+      if (depth_state->test_enabled == TRUE)
+        GE (ctx, glEnable (GL_DEPTH_TEST));
+      else
+        GE (ctx, glDisable (GL_DEPTH_TEST));
+      ctx->depth_test_enabled_cache = depth_state->test_enabled;
+    }
 
-  if (ctx->depth_test_function_cache != depth_state->test_function)
+  if (ctx->depth_test_function_cache != depth_state->test_function &&
+      depth_state->test_enabled == TRUE)
     {
       GE (ctx, glDepthFunc (depth_state->test_function));
       ctx->depth_test_function_cache = depth_state->test_function;
@@ -438,7 +447,7 @@ static void
 _cogl_pipeline_flush_color_blend_alpha_depth_state (
                                             CoglPipeline *pipeline,
                                             unsigned long pipelines_difference,
-                                            gboolean      skip_gl_color)
+                                            CoglBool      skip_gl_color)
 {
   _COGL_GET_CONTEXT (ctx, NO_RETVAL);
 
@@ -571,20 +580,7 @@ _cogl_pipeline_flush_color_blend_alpha_depth_state (
         _cogl_pipeline_get_authority (pipeline, COGL_PIPELINE_STATE_DEPTH);
       CoglDepthState *depth_state = &authority->big_state->depth_state;
 
-      if (depth_state->test_enabled)
-        {
-          if (ctx->depth_test_enabled_cache != TRUE)
-            {
-              GE (ctx, glEnable (GL_DEPTH_TEST));
-              ctx->depth_test_enabled_cache = depth_state->test_enabled;
-            }
-          flush_depth_state (depth_state);
-        }
-      else if (ctx->depth_test_enabled_cache != FALSE)
-        {
-          GE (ctx, glDisable (GL_DEPTH_TEST));
-          ctx->depth_test_enabled_cache = depth_state->test_enabled;
-        }
+      flush_depth_state (ctx, depth_state);
     }
 
   if (pipelines_difference & COGL_PIPELINE_STATE_LOGIC_OPS)
@@ -615,7 +611,7 @@ _cogl_pipeline_flush_color_blend_alpha_depth_state (
         GE( ctx, glDisable (GL_CULL_FACE) );
       else
         {
-          gboolean invert_winding;
+          CoglBool invert_winding;
 
           GE( ctx, glEnable (GL_CULL_FACE) );
 
@@ -747,7 +743,7 @@ typedef struct
   unsigned long *layer_differences;
 } CoglPipelineFlushLayerState;
 
-static gboolean
+static CoglBool
 flush_layers_common_gl_state_cb (CoglPipelineLayer *layer, void *user_data)
 {
   CoglPipelineFlushLayerState *flush_state = user_data;
@@ -763,7 +759,7 @@ flush_layers_common_gl_state_cb (CoglPipelineLayer *layer, void *user_data)
    */
   if (G_UNLIKELY (unit_index >= get_max_activateable_texture_units ()))
     {
-      static gboolean shown_warning = FALSE;
+      static CoglBool shown_warning = FALSE;
 
       if (!shown_warning)
         {
@@ -844,6 +840,16 @@ flush_layers_common_gl_state_cb (CoglPipelineLayer *layer, void *user_data)
       unit->texture_storage_changed = FALSE;
     }
 
+  if ((layers_difference & COGL_PIPELINE_LAYER_STATE_SAMPLER) &&
+      (ctx->private_feature_flags & COGL_PRIVATE_FEATURE_SAMPLER_OBJECTS))
+    {
+      const CoglSamplerCacheEntry *sampler_state;
+
+      sampler_state = _cogl_pipeline_layer_get_sampler_state (layer);
+
+      GE( ctx, glBindSampler (unit_index, sampler_state->sampler_object) );
+    }
+
   /* Under GLES2 the fragment shader will use gl_PointCoord instead of
      replacing the texture coordinates */
 #if defined (HAVE_COGL_GLES) || defined (HAVE_COGL_GL)
@@ -862,9 +868,9 @@ flush_layers_common_gl_state_cb (CoglPipelineLayer *layer, void *user_data)
     }
 #endif
 
-  cogl_handle_ref (layer);
-  if (unit->layer != COGL_INVALID_HANDLE)
-    cogl_handle_unref (unit->layer);
+  cogl_object_ref (layer);
+  if (unit->layer != NULL)
+    cogl_object_unref (unit->layer);
 
   unit->layer = layer;
   unit->layer_changes_since_flush = 0;
@@ -878,7 +884,7 @@ static void
 _cogl_pipeline_flush_common_gl_state (CoglPipeline  *pipeline,
                                       unsigned long  pipelines_difference,
                                       unsigned long *layer_differences,
-                                      gboolean       skip_gl_color)
+                                      CoglBool       skip_gl_color)
 {
   CoglPipelineFlushLayerState state;
 
@@ -904,7 +910,7 @@ static void
 _cogl_pipeline_layer_forward_wrap_modes (CoglPipelineLayer *layer,
                                          CoglTexture *texture)
 {
-  CoglPipelineWrapModeInternal wrap_mode_s, wrap_mode_t, wrap_mode_p;
+  CoglSamplerCacheWrapMode wrap_mode_s, wrap_mode_t, wrap_mode_p;
   GLenum gl_wrap_mode_s, gl_wrap_mode_t, gl_wrap_mode_p;
 
   if (texture == NULL)
@@ -926,17 +932,17 @@ _cogl_pipeline_layer_forward_wrap_modes (CoglPipelineLayer *layer,
      will break if the application tries to use different modes in
      different layers using the same texture. */
 
-  if (wrap_mode_s == COGL_PIPELINE_WRAP_MODE_INTERNAL_AUTOMATIC)
+  if (wrap_mode_s == COGL_SAMPLER_CACHE_WRAP_MODE_AUTOMATIC)
     gl_wrap_mode_s = GL_CLAMP_TO_EDGE;
   else
     gl_wrap_mode_s = wrap_mode_s;
 
-  if (wrap_mode_t == COGL_PIPELINE_WRAP_MODE_INTERNAL_AUTOMATIC)
+  if (wrap_mode_t == COGL_SAMPLER_CACHE_WRAP_MODE_AUTOMATIC)
     gl_wrap_mode_t = GL_CLAMP_TO_EDGE;
   else
     gl_wrap_mode_t = wrap_mode_t;
 
-  if (wrap_mode_p == COGL_PIPELINE_WRAP_MODE_INTERNAL_AUTOMATIC)
+  if (wrap_mode_p == COGL_SAMPLER_CACHE_WRAP_MODE_AUTOMATIC)
     gl_wrap_mode_p = GL_CLAMP_TO_EDGE;
   else
     gl_wrap_mode_p = wrap_mode_p;
@@ -952,8 +958,10 @@ _cogl_pipeline_layer_forward_wrap_modes (CoglPipelineLayer *layer,
  * the filter and repeat modes whenever we use a texture since it may
  * be referenced by multiple pipelines with different modes.
  *
- * XXX: GL_ARB_sampler_objects fixes this in OpenGL so we should
- * eventually look at using this extension when available.
+ * This function is bypassed in favour of sampler objects if
+ * GL_ARB_sampler_objects is advertised. This fallback won't work if
+ * the same texture is bound to multiple layers with different sampler
+ * state.
  */
 static void
 foreach_texture_unit_update_filter_and_wrap_modes (void)
@@ -991,7 +999,7 @@ typedef struct
   unsigned long *layer_differences;
 } CoglPipelineCompareLayersState;
 
-static gboolean
+static CoglBool
 compare_layer_differences_cb (CoglPipelineLayer *layer, void *user_data)
 {
   CoglPipelineCompareLayersState *state = user_data;
@@ -1030,12 +1038,12 @@ typedef struct
   const CoglPipelineFragend *fragend;
   CoglPipeline *pipeline;
   unsigned long *layer_differences;
-  gboolean error_adding_layer;
-  gboolean added_layer;
+  CoglBool error_adding_layer;
+  CoglBool added_layer;
 } CoglPipelineFragendAddLayerState;
 
 
-static gboolean
+static CoglBool
 fragend_add_layer_cb (CoglPipelineLayer *layer,
                       void *user_data)
 {
@@ -1044,8 +1052,6 @@ fragend_add_layer_cb (CoglPipelineLayer *layer,
   CoglPipeline *pipeline = state->pipeline;
   int unit_index = _cogl_pipeline_layer_get_unit_index (layer);
 
-  _COGL_GET_CONTEXT (ctx, FALSE);
-
   /* Either generate per layer code snippets or setup the
    * fixed function glTexEnv for each layer... */
   if (G_LIKELY (fragend->add_layer (pipeline,
@@ -1063,15 +1069,16 @@ fragend_add_layer_cb (CoglPipelineLayer *layer,
 
 typedef struct
 {
+  CoglFramebuffer *framebuffer;
   const CoglPipelineVertend *vertend;
   CoglPipeline *pipeline;
   unsigned long *layer_differences;
-  gboolean error_adding_layer;
-  gboolean added_layer;
+  CoglBool error_adding_layer;
+  CoglBool added_layer;
 } CoglPipelineVertendAddLayerState;
 
 
-static gboolean
+static CoglBool
 vertend_add_layer_cb (CoglPipelineLayer *layer,
                       void *user_data)
 {
@@ -1080,13 +1087,12 @@ vertend_add_layer_cb (CoglPipelineLayer *layer,
   CoglPipeline *pipeline = state->pipeline;
   int unit_index = _cogl_pipeline_layer_get_unit_index (layer);
 
-  _COGL_GET_CONTEXT (ctx, FALSE);
-
   /* Either enerate per layer code snippets or setup the
    * fixed function matrix uniforms for each layer... */
   if (G_LIKELY (vertend->add_layer (pipeline,
                                     layer,
-                                    state->layer_differences[unit_index])))
+                                    state->layer_differences[unit_index],
+                                    state->framebuffer)))
     state->added_layer = TRUE;
   else
     {
@@ -1149,7 +1155,8 @@ vertend_add_layer_cb (CoglPipelineLayer *layer,
  */
 void
 _cogl_pipeline_flush_gl_state (CoglPipeline *pipeline,
-                               gboolean skip_gl_color,
+                               CoglFramebuffer *framebuffer,
+                               CoglBool skip_gl_color,
                                int n_tex_coord_attribs)
 {
   unsigned long    pipelines_difference;
@@ -1318,6 +1325,7 @@ _cogl_pipeline_flush_gl_state (CoglPipeline *pipeline,
                                        n_tex_coord_attribs)))
         continue;
 
+      state.framebuffer = framebuffer;
       state.vertend = vertend;
       state.pipeline = pipeline;
       state.layer_differences = layer_differences;
@@ -1395,11 +1403,12 @@ done:
      matrices */
   for (i = 0; i < COGL_PIPELINE_N_PROGENDS; i++)
     if (_cogl_pipeline_progends[i]->pre_paint)
-      _cogl_pipeline_progends[i]->pre_paint (pipeline);
+      _cogl_pipeline_progends[i]->pre_paint (pipeline, framebuffer);
 
   /* Handle the fact that OpenGL associates texture filter and wrap
    * modes with the texture objects not the texture units... */
-  foreach_texture_unit_update_filter_and_wrap_modes ();
+  if (!(ctx->private_feature_flags & COGL_PRIVATE_FEATURE_SAMPLER_OBJECTS))
+    foreach_texture_unit_update_filter_and_wrap_modes ();
 
   /* If this pipeline has more than one layer then we always need
    * to make sure we rebind the texture for unit 1.
