@@ -41,7 +41,7 @@
 struct _CoglRenderer
 {
   CoglObject _parent;
-  gboolean connected;
+  CoglBool connected;
   CoglDriver driver_override;
   const CoglWinsysVtable *winsys_vtable;
   CoglWinsysID winsys_id_override;
@@ -49,7 +49,7 @@ struct _CoglRenderer
 
 #ifdef COGL_HAS_XLIB_SUPPORT
   Display *foreign_xdpy;
-  gboolean xlib_enable_event_retrieval;
+  CoglBool xlib_enable_event_retrieval;
 #endif
 
   CoglDriver driver;
@@ -62,6 +62,12 @@ struct _CoglRenderer
   struct wl_compositor *foreign_wayland_compositor;
   struct wl_shell *foreign_wayland_shell;
 #endif
+
+#ifdef COGL_HAS_SDL_SUPPORT
+  CoglBool sdl_event_type_set;
+  uint8_t sdl_event_type;
+#endif
+
   /* List of callback functions that will be given every native event */
   GSList *event_filters;
   void *winsys;
@@ -86,6 +92,7 @@ _cogl_renderer_remove_native_filter (CoglRenderer *renderer,
 
 void *
 _cogl_renderer_get_proc_address (CoglRenderer *renderer,
-                                 const char *name);
+                                 const char *name,
+                                 CoglBool in_core);
 
 #endif /* __COGL_RENDERER_PRIVATE_H */
