@@ -46,13 +46,31 @@ typedef struct _CoglRendererSdl
 typedef struct _CoglDisplaySdl
 {
   SDL_Surface *surface;
-  gboolean has_onscreen;
+  CoglOnscreen *onscreen;
+  Uint32 video_mode_flags;
+  CoglBool pending_resize_notify;
 } CoglDisplaySdl;
 
 static CoglFuncPtr
 _cogl_winsys_renderer_get_proc_address (CoglRenderer *renderer,
-                                        const char *name)
+                                        const char *name,
+                                        CoglBool in_core)
 {
+  /* XXX: It's not totally clear whether it's safe to call this for
+   * core functions. From the code it looks like the implementations
+   * will fall back to using some form of dlsym if the winsys
+   * GetProcAddress function returns NULL. Presumably this will work
+   * in most cases apart from EGL platforms that return invalid
+   * pointers for core functions. It's awkward for this code to get a
+   * handle to the GL module that SDL has chosen to load so just
+   * calling SDL_GL_GetProcAddress is probably the best we can do
+   * here. */
+
+#ifdef COGL_HAS_SDL_GLES_SUPPORT
+  if (renderer->driver != COGL_DRIVER_GL)
+    return SDL_GLES_GetProcAddress (name);
+#endif
+
   return SDL_GL_GetProcAddress (name);
 }
 
@@ -64,10 +82,11 @@ _cogl_winsys_renderer_disconnect (CoglRenderer *renderer)
   g_slice_free (CoglRendererSdl, renderer->winsys);
 }
 
-static gboolean
+static CoglBool
 _cogl_winsys_renderer_connect (CoglRenderer *renderer,
                                GError **error)
 {
+#ifndef COGL_HAS_SDL_GLES_SUPPORT
   if (renderer->driver != COGL_DRIVER_GL)
     {
       g_set_error (error, COGL_WINSYS_ERROR,
@@ -75,6 +94,7 @@ _cogl_winsys_renderer_connect (CoglRenderer *renderer,
                    "The SDL winsys only supports the GL driver");
       return FALSE;
     }
+#endif /* COGL_HAS_SDL_GLES_SUPPORT */
 
   if (SDL_Init (SDL_INIT_VIDEO) == -1)
     {
@@ -121,7 +141,7 @@ set_gl_attribs_from_framebuffer_config (CoglFramebufferConfig *config)
                        config->swap_chain->has_alpha ? 1 : 0);
 }
 
-static gboolean
+static CoglBool
 _cogl_winsys_display_setup (CoglDisplay *display,
                             GError **error)
 {
@@ -134,11 +154,37 @@ _cogl_winsys_display_setup (CoglDisplay *display,
 
   set_gl_attribs_from_framebuffer_config (&display->onscreen_template->config);
 
+  switch (display->renderer->driver)
+    {
+    case COGL_DRIVER_GL:
+      sdl_display->video_mode_flags = SDL_OPENGL;
+      break;
+
+#ifdef COGL_HAS_SDL_GLES_SUPPORT
+    case COGL_DRIVER_GLES2:
+      sdl_display->video_mode_flags = SDL_OPENGLES;
+      SDL_GL_SetAttribute (SDL_GL_CONTEXT_MAJOR_VERSION, 2);
+      SDL_GL_SetAttribute (SDL_GL_CONTEXT_MINOR_VERSION, 0);
+      break;
+
+    case COGL_DRIVER_GLES1:
+      sdl_display->video_mode_flags = SDL_OPENGLES;
+      SDL_GL_SetAttribute (SDL_GL_CONTEXT_MAJOR_VERSION, 1);
+      SDL_GL_SetAttribute (SDL_GL_CONTEXT_MINOR_VERSION, 1);
+      break;
+#endif /* COGL_HAS_SDL_GLES_SUPPORT */
+
+    default:
+      g_assert_not_reached ();
+    }
+
   /* There's no way to know what size the application will need until
      it creates the first onscreen but we need to set the video mode
      now so that we can get a GL context. We'll have to just guess at
      a size an resize it later */
-  sdl_display->surface = SDL_SetVideoMode (640, 480, 0, SDL_OPENGL);
+  sdl_display->surface = SDL_SetVideoMode (640, 480, /* width/height */
+                                           0, /* bitsperpixel */
+                                           sdl_display->video_mode_flags);
 
   if (sdl_display->surface == NULL)
     {
@@ -156,9 +202,52 @@ error:
   return FALSE;
 }
 
-static gboolean
+static CoglFilterReturn
+sdl_event_filter_cb (SDL_Event *event, void *data)
+{
+  if (event->type == SDL_VIDEORESIZE)
+    {
+      CoglContext *context = data;
+      CoglDisplay *display = context->display;
+      CoglDisplaySdl *sdl_display = display->winsys;
+      float width = event->resize.w;
+      float height = event->resize.h;
+      CoglFramebuffer *framebuffer;
+
+      if (!sdl_display->onscreen)
+        return COGL_FILTER_CONTINUE;
+
+      sdl_display->surface = SDL_SetVideoMode (width, height,
+                                               0, /* bitsperpixel */
+                                               sdl_display->video_mode_flags);
+
+      framebuffer = COGL_FRAMEBUFFER (sdl_display->onscreen);
+      _cogl_framebuffer_winsys_update_size (framebuffer, width, height);
+
+      /* We only want to notify that a resize happened when the
+         application calls cogl_context_dispatch so instead of immediately
+         notifying we'll set a flag to remember to notify later */
+      sdl_display->pending_resize_notify = TRUE;
+
+      return COGL_FILTER_CONTINUE;
+    }
+
+  return COGL_FILTER_CONTINUE;
+}
+
+static CoglBool
 _cogl_winsys_context_init (CoglContext *context, GError **error)
 {
+  CoglRenderer *renderer = context->display->renderer;
+
+  if (G_UNLIKELY (renderer->sdl_event_type_set == FALSE))
+    g_error ("cogl_sdl_renderer_set_event_type() or cogl_sdl_context_new() "
+             "must be called during initialization");
+
+  _cogl_renderer_add_native_filter (renderer,
+                                    (CoglNativeFilterFunc)sdl_event_filter_cb,
+                                    context);
+
   return _cogl_context_update_features (context, error);
 }
 
@@ -179,10 +268,10 @@ _cogl_winsys_onscreen_deinit (CoglOnscreen *onscreen)
   CoglDisplay *display = context->display;
   CoglDisplaySdl *sdl_display = display->winsys;
 
-  sdl_display->has_onscreen = FALSE;
+  sdl_display->onscreen = NULL;
 }
 
-static gboolean
+static CoglBool
 _cogl_winsys_onscreen_init (CoglOnscreen *onscreen,
                             GError **error)
 {
@@ -192,7 +281,7 @@ _cogl_winsys_onscreen_init (CoglOnscreen *onscreen,
   CoglDisplaySdl *sdl_display = display->winsys;
   int width, height;
 
-  if (sdl_display->has_onscreen)
+  if (sdl_display->onscreen)
     {
       g_set_error (error, COGL_WINSYS_ERROR,
                    COGL_WINSYS_ERROR_CREATE_ONSCREEN,
@@ -207,7 +296,9 @@ _cogl_winsys_onscreen_init (CoglOnscreen *onscreen,
   if (width != sdl_display->surface->w ||
       height != sdl_display->surface->h)
     {
-      sdl_display->surface = SDL_SetVideoMode (width, height, 0, SDL_OPENGL);
+      sdl_display->surface = SDL_SetVideoMode (width, height,
+                                               0, /* bitsperpixel */
+                                               sdl_display->video_mode_flags);
 
       if (sdl_display->surface == NULL)
         {
@@ -223,7 +314,7 @@ _cogl_winsys_onscreen_init (CoglOnscreen *onscreen,
                                         sdl_display->surface->w,
                                         sdl_display->surface->h);
 
-  sdl_display->has_onscreen = TRUE;
+  sdl_display->onscreen = onscreen;
 
   return TRUE;
 }
@@ -242,15 +333,58 @@ _cogl_winsys_onscreen_update_swap_throttled (CoglOnscreen *onscreen)
 
 static void
 _cogl_winsys_onscreen_set_visibility (CoglOnscreen *onscreen,
-                                      gboolean visibility)
+                                      CoglBool visibility)
 {
   /* SDL doesn't appear to provide a way to set this */
 }
 
+static void
+_cogl_winsys_onscreen_set_resizable (CoglOnscreen *onscreen,
+                                     CoglBool resizable)
+{
+  CoglFramebuffer *framebuffer = COGL_FRAMEBUFFER (onscreen);
+  CoglContext *context = framebuffer->context;
+  CoglDisplay *display = context->display;
+  CoglDisplaySdl *sdl_display = display->winsys;
+  int width, height;
+
+  width = cogl_framebuffer_get_width (framebuffer);
+  height = cogl_framebuffer_get_height (framebuffer);
+
+  if (resizable)
+    sdl_display->video_mode_flags |= SDL_RESIZABLE;
+  else
+    sdl_display->video_mode_flags &= ~SDL_RESIZABLE;
+
+  sdl_display->surface = SDL_SetVideoMode (width, height,
+                                           0, /* bitsperpixel */
+                                           sdl_display->video_mode_flags);
+}
+
+static void
+_cogl_winsys_poll_dispatch (CoglContext *context,
+                            const CoglPollFD *poll_fds,
+                            int n_poll_fds)
+{
+  CoglDisplay *display = context->display;
+  CoglDisplaySdl *sdl_display = display->winsys;
+
+  if (sdl_display->pending_resize_notify)
+    {
+      CoglOnscreen *onscreen = sdl_display->onscreen;
+
+      g_return_if_fail (onscreen != NULL);
+
+      _cogl_onscreen_notify_resize (onscreen);
+
+      sdl_display->pending_resize_notify = FALSE;
+    }
+}
+
 const CoglWinsysVtable *
 _cogl_winsys_sdl_get_vtable (void)
 {
-  static gboolean vtable_inited = FALSE;
+  static CoglBool vtable_inited = FALSE;
   static CoglWinsysVtable vtable;
 
   /* It would be nice if we could use C99 struct initializers here
@@ -278,6 +412,9 @@ _cogl_winsys_sdl_get_vtable (void)
       vtable.onscreen_update_swap_throttled =
         _cogl_winsys_onscreen_update_swap_throttled;
       vtable.onscreen_set_visibility = _cogl_winsys_onscreen_set_visibility;
+      vtable.onscreen_set_resizable = _cogl_winsys_onscreen_set_resizable;
+
+      vtable.poll_dispatch = _cogl_winsys_poll_dispatch;
 
       vtable_inited = TRUE;
     }
