@@ -76,7 +76,7 @@ typedef struct _CoglDisplayWgl
 typedef struct _CoglOnscreenWin32
 {
   HWND hwnd;
-  gboolean is_foreign_hwnd;
+  CoglBool is_foreign_hwnd;
 } CoglOnscreenWin32;
 
 typedef struct _CoglContextWgl
@@ -127,14 +127,22 @@ static const CoglFeatureData winsys_feature_data[] =
 
 static CoglFuncPtr
 _cogl_winsys_renderer_get_proc_address (CoglRenderer *renderer,
-                                        const char *name)
+                                        const char *name,
+                                        CoglBool in_core)
 {
   CoglRendererWgl *wgl_renderer = renderer->winsys;
   void *proc = wglGetProcAddress ((LPCSTR) name);
 
   /* The documentation for wglGetProcAddress implies that it only
      returns pointers to extension functions so if it fails we'll try
-     resolving the symbol directly from the the GL library */
+     resolving the symbol directly from the the GL library. We could
+     completely avoid using wglGetProcAddress if in_core is TRUE but
+     on WGL any function that is in GL > 1.1 is considered an
+     extension and is not directly exported from opengl32.dll.
+     Therefore we currently just assume wglGetProcAddress will return
+     NULL for GL 1.1 functions and we can fallback to querying them
+     directly from the library */
+
   if (proc == NULL)
     {
       if (wgl_renderer->gl_module == NULL)
@@ -222,7 +230,7 @@ win32_event_filter_cb (MSG *msg, void *data)
   return COGL_FILTER_CONTINUE;
 }
 
-static gboolean
+static CoglBool
 _cogl_winsys_renderer_connect (CoglRenderer *renderer,
                                GError **error)
 {
@@ -235,7 +243,7 @@ static LRESULT CALLBACK
 window_proc (HWND hwnd, UINT umsg,
              WPARAM wparam, LPARAM lparam)
 {
-  gboolean message_handled = FALSE;
+  CoglBool message_handled = FALSE;
   CoglOnscreen *onscreen;
 
   /* It's not clear what the best thing to do with messages sent to
@@ -294,7 +302,7 @@ window_proc (HWND hwnd, UINT umsg,
     return 0;
 }
 
-static gboolean
+static CoglBool
 pixel_format_is_better (const PIXELFORMATDESCRIPTOR *pfa,
                         const PIXELFORMATDESCRIPTOR *pfb)
 {
@@ -363,7 +371,7 @@ choose_pixel_format (CoglFramebufferConfig *config,
   return best_pf;
 }
 
-static gboolean
+static CoglBool
 create_window_class (CoglDisplay *display, GError **error)
 {
   CoglDisplayWgl *wgl_display = display->winsys;
@@ -416,7 +424,7 @@ create_window_class (CoglDisplay *display, GError **error)
   return TRUE;
 }
 
-static gboolean
+static CoglBool
 create_context (CoglDisplay *display, GError **error)
 {
   CoglDisplayWgl *wgl_display = display->winsys;
@@ -519,7 +527,7 @@ _cogl_winsys_display_destroy (CoglDisplay *display)
   display->winsys = NULL;
 }
 
-static gboolean
+static CoglBool
 _cogl_winsys_display_setup (CoglDisplay *display,
                             GError **error)
 {
@@ -572,13 +580,13 @@ get_wgl_extensions_string (HDC dc)
      extensions isn't supported then we can at least fake it to
      support the swap control extension */
   if (_cogl_check_extension ("WGL_EXT_swap_control",
-                             (char *) ctx->glGetString (GL_EXTENSIONS)))
+                             _cogl_context_get_gl_extensions (ctx)))
     return "WGL_EXT_swap_control";
 
   return NULL;
 }
 
-static gboolean
+static CoglBool
 update_winsys_features (CoglContext *context, GError **error)
 {
   CoglDisplayWgl *wgl_display = context->display->winsys;
@@ -624,7 +632,7 @@ update_winsys_features (CoglContext *context, GError **error)
   return TRUE;
 }
 
-static gboolean
+static CoglBool
 _cogl_winsys_context_init (CoglContext *context, GError **error)
 {
   CoglContextWgl *wgl_context;
@@ -723,7 +731,7 @@ _cogl_winsys_onscreen_deinit (CoglOnscreen *onscreen)
   onscreen->winsys = NULL;
 }
 
-static gboolean
+static CoglBool
 _cogl_winsys_onscreen_init (CoglOnscreen *onscreen,
                             GError **error)
 {
@@ -850,7 +858,7 @@ _cogl_winsys_onscreen_win32_get_window (CoglOnscreen *onscreen)
 
 static void
 _cogl_winsys_onscreen_set_visibility (CoglOnscreen *onscreen,
-                                      gboolean visibility)
+                                      CoglBool visibility)
 {
   CoglOnscreenWin32 *win32_onscreen = onscreen->winsys;
 
@@ -860,7 +868,7 @@ _cogl_winsys_onscreen_set_visibility (CoglOnscreen *onscreen,
 const CoglWinsysVtable *
 _cogl_winsys_wgl_get_vtable (void)
 {
-  static gboolean vtable_inited = FALSE;
+  static CoglBool vtable_inited = FALSE;
   static CoglWinsysVtable vtable;
 
   /* It would be nice if we could use C99 struct initializers here
