@@ -15,12 +15,12 @@
 
 static void
 update_cogl_x11_event_mask (CoglOnscreen *onscreen,
-                            guint32 event_mask,
+                            uint32_t event_mask,
                             void *user_data)
 {
   Display *xdpy = user_data;
   XSetWindowAttributes attrs;
-  guint32 xwin;
+  uint32_t xwin;
 
   attrs.event_mask = event_mask | X11_FOREIGN_EVENT_MASK;
   xwin = cogl_x11_onscreen_get_window_xid (onscreen);
@@ -31,6 +31,16 @@ update_cogl_x11_event_mask (CoglOnscreen *onscreen,
                            &attrs);
 }
 
+static void
+resize_handler (CoglOnscreen *onscreen,
+                int width,
+                int height,
+                void *user_data)
+{
+  CoglFramebuffer *fb = user_data;
+  cogl_framebuffer_set_viewport (fb, width / 4, height / 4, width / 2, height / 2);
+}
+
 int
 main (int argc, char **argv)
 {
@@ -44,7 +54,7 @@ main (int argc, char **argv)
   CoglFramebuffer *fb;
   CoglPipeline *pipeline;
   GError *error = NULL;
-  guint32 visual;
+  uint32_t visual;
   XVisualInfo template, *xvisinfo;
   int visinfos_count;
   XSetWindowAttributes xattr;
@@ -149,6 +159,9 @@ main (int argc, char **argv)
 
   fb = COGL_FRAMEBUFFER (onscreen);
 
+  cogl_onscreen_set_resizable (onscreen, TRUE);
+  cogl_onscreen_add_resize_handler (onscreen, resize_handler, onscreen);
+
   triangle = cogl_primitive_new_p2c4 (ctx, COGL_VERTICES_MODE_TRIANGLES,
                                       3, triangle_vertices);
   pipeline = cogl_pipeline_new (ctx);
@@ -156,7 +169,7 @@ main (int argc, char **argv)
     {
       CoglPollFD *poll_fds;
       int n_poll_fds;
-      gint64 timeout;
+      int64_t timeout;
 
       while (XPending (xdpy))
         {
@@ -170,13 +183,18 @@ main (int argc, char **argv)
             }
           cogl_xlib_renderer_handle_event (renderer, &event);
         }
-      cogl_framebuffer_clear4f (fb, COGL_BUFFER_BIT_COLOR, 0, 0, 0, 1);
-      cogl_framebuffer_draw_primitive (fb, pipeline, triangle);
-      cogl_onscreen_swap_buffers (onscreen);
 
+      /* After forwarding native events directly to Cogl you should
+       * then allow Cogl to dispatch any corresponding event
+       * callbacks, such as resize notification callbacks...
+       */
       cogl_poll_get_info (ctx, &poll_fds, &n_poll_fds, &timeout);
       g_poll ((GPollFD *) poll_fds, n_poll_fds, 0);
       cogl_poll_dispatch (ctx, poll_fds, n_poll_fds);
+
+      cogl_framebuffer_clear4f (fb, COGL_BUFFER_BIT_COLOR, 0, 0, 0, 1);
+      cogl_framebuffer_draw_primitive (fb, pipeline, triangle);
+      cogl_onscreen_swap_buffers (onscreen);
     }
 
   return 0;
