@@ -21,12 +21,12 @@
 
 static void
 update_cogl_x11_event_mask (CoglOnscreen *onscreen,
-                            guint32 event_mask,
+                            uint32_t event_mask,
                             void *user_data)
 {
   Display *xdpy = user_data;
   XSetWindowAttributes attrs;
-  guint32 xwin;
+  uint32_t xwin;
 
   attrs.event_mask = event_mask | X11_FOREIGN_EVENT_MASK;
   xwin = cogl_x11_onscreen_get_window_xid (onscreen);
@@ -50,7 +50,7 @@ main (int argc, char **argv)
   CoglOnscreen *onscreen;
   CoglFramebuffer *fb;
   GError *error = NULL;
-  guint32 visual;
+  uint32_t visual;
   XVisualInfo template, *xvisinfo;
   int visinfos_count;
   XSetWindowAttributes xattr;
