@@ -53,12 +53,13 @@ main (int argc, char **argv)
   UNPORTED_TEST (test_materials);
   ADD_TEST (test_pipeline_user_matrix, 0);
   ADD_TEST (test_blend_strings, 0);
-  UNPORTED_TEST (test_premult);
+  ADD_TEST (test_premult, 0);
   UNPORTED_TEST (test_readpixels);
   ADD_TEST (test_path, 0);
   ADD_TEST (test_depth_test, 0);
   ADD_TEST (test_color_mask, 0);
   ADD_TEST (test_backface_culling, TEST_REQUIREMENT_NPOT);
+  ADD_TEST (test_layer_remove, 0);
 
   ADD_TEST (test_sparse_pipeline, 0);
 
@@ -72,7 +73,7 @@ main (int argc, char **argv)
   ADD_TEST (test_wrap_modes, 0);
   UNPORTED_TEST (test_texture_pixmap_x11);
   UNPORTED_TEST (test_texture_get_set_data);
-  UNPORTED_TEST (test_atlas_migration);
+  ADD_TEST (test_atlas_migration, 0);
   ADD_TEST (test_read_texture_formats, 0);
   ADD_TEST (test_write_texture_formats, 0);
 
@@ -93,10 +94,20 @@ main (int argc, char **argv)
 
   ADD_TEST (test_point_size, 0);
   ADD_TEST (test_point_sprite,
+            TEST_REQUIREMENT_POINT_SPRITE);
+  ADD_TEST (test_point_sprite_orientation,
             TEST_KNOWN_FAILURE | TEST_REQUIREMENT_POINT_SPRITE);
 
+  ADD_TEST (test_version, 0);
+
   UNPORTED_TEST (test_viewport);
 
+  ADD_TEST (test_gles2_context, TEST_REQUIREMENT_GLES2_CONTEXT);
+  ADD_TEST (test_gles2_context_fbo, TEST_REQUIREMENT_GLES2_CONTEXT);
+  ADD_TEST (test_gles2_context_copy_tex_image, TEST_REQUIREMENT_GLES2_CONTEXT);
+
+  ADD_TEST (test_euler_quaternion, 0);
+
   g_printerr ("Unknown test name \"%s\"\n", argv[1]);
 
   return 1;
